Index: main/waeup.uniben/trunk/src/waeup/uniben/README.txt
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/README.txt	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/README.txt	(revision 8020)
@@ -1,3 +1,3 @@
-The waeup.custom package
+The waeup.uniben package
 ************************
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/applicant.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/applicants/applicant.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/applicants/applicant.py	(revision 8020)
@@ -22,5 +22,5 @@
 from waeup.kofa.applicants.interfaces import IApplicantEdit
 from waeup.kofa.utils.helpers import attrs_to_fields
-from waeup.custom.applicants.interfaces import(
+from waeup.uniben.applicants.interfaces import(
     IApplicant, IUGApplicantEdit, IPGApplicantEdit)
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/applicants/browser.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/applicants/browser.py	(revision 8020)
@@ -29,7 +29,7 @@
 from waeup.kofa.applicants.pdf import PDFApplicationSlip
 #from waeup.kofa.applicants.interfaces import IApplicant, IApplicantEdit
-from waeup.custom.applicants.interfaces import (
+from waeup.uniben.applicants.interfaces import (
     IPGApplicant, IUGApplicant, IPGApplicantEdit, IUGApplicantEdit)
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.interfaces import MessageFactory as _
 
 class RequestCallbackActionButton(RequestCallbackActionButton):
Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/interfaces.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/applicants/interfaces.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/applicants/interfaces.py	(revision 8020)
@@ -21,5 +21,5 @@
 from zope import schema
 from waeup.kofa.applicants.interfaces import IApplicant, IApplicantProcessData
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.interfaces import MessageFactory as _
 
 class IUGApplicant(IApplicant):
Index: main/waeup.uniben/trunk/src/waeup/uniben/applicants/tests.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/applicants/tests.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/applicants/tests.py	(revision 8020)
@@ -28,5 +28,5 @@
 from waeup.kofa.testing import FunctionalTestCase
 from waeup.kofa.applicants.container import ApplicantsContainer
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 from waeup.kofa.interfaces import IBatchProcessor
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/browser/pages.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/browser/pages.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/browser/pages.py	(revision 8020)
@@ -19,5 +19,5 @@
 from waeup.kofa.browser.pages import (
     SessionConfigurationAddFormPage, SessionConfigurationManageFormPage)
-from waeup.custom.interfaces import (
+from waeup.uniben.interfaces import (
     ISessionConfiguration, ISessionConfigurationAdd)
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/browser/resources.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/browser/resources.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/browser/resources.py	(revision 8020)
@@ -22,8 +22,8 @@
 
 #: All local resources are registered under the name ``waeup_custom``.
-waeup_custom = Library('waeup_custom', 'static')
+waeup_uniben = Library('waeup_uniben', 'static')
 
 custom_theme_1 = ResourceInclusion(
-    waeup_custom, 'custom_theme_1.css',
+    waeup_uniben, 'custom_theme_1.css',
     depends = [waeup_base_css])
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/browser/tests.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/browser/tests.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/browser/tests.py	(revision 8020)
@@ -21,5 +21,5 @@
 from zope.component.hooks import setSite, clearSite
 from waeup.kofa.testing import FunctionalTestCase
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 from waeup.kofa.app import University
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/browser/theming.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/browser/theming.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/browser/theming.py	(revision 8020)
@@ -18,7 +18,7 @@
 import grok
 from waeup.kofa.browser.interfaces import ITheme
-from waeup.custom.browser.resources import custom_theme_1
+from waeup.uniben.browser.resources import custom_theme_1
 
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.interfaces import MessageFactory as _
 
 class CustomTheme1(grok.GlobalUtility):
Index: main/waeup.uniben/trunk/src/waeup/uniben/configuration.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/configuration.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/configuration.py	(revision 8020)
@@ -24,5 +24,5 @@
 from waeup.kofa.configuration import (
     SessionConfigurationFactory, SessionConfiguration)
-from waeup.custom.interfaces import (
+from waeup.uniben.interfaces import (
     ISessionConfiguration, ISessionConfigurationAdd)
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/configure.zcml
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/configure.zcml	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/configure.zcml	(revision 8020)
@@ -4,4 +4,4 @@
   <include package="grok" />
   <i18n:registerTranslations directory="locales" />
-  <includeOverrides package="waeup.custom" file="overrides.zcml" />
+  <includeOverrides package="waeup.uniben" file="overrides.zcml" />
 </configure>
Index: main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/etranzact/browser.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser.py	(revision 8020)
@@ -25,6 +25,6 @@
 from waeup.kofa.students.browser import write_log_message
 from waeup.kofa.students.viewlets import RequestCallbackActionButton
-from waeup.custom.interfaces import MessageFactory as _
-from waeup.custom.utils.utils import actions_after_payment
+from waeup.uniben.interfaces import MessageFactory as _
+from waeup.uniben.utils.utils import actions_after_payment
 
 TERMINAL_ID = '0000000001'
Index: main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser_templates/enterpin.pt
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/etranzact/browser_templates/enterpin.pt	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/etranzact/browser_templates/enterpin.pt	(revision 8020)
@@ -1,4 +1,4 @@
 <form tal:attributes="action view/action"
-    method="POST" i18n:domain="waeup.custom">
+    method="POST" i18n:domain="waeup.uniben">
   <table class="form-table">
     <tbody>
Index: main/waeup.uniben/trunk/src/waeup/uniben/etranzact/tests.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/etranzact/tests.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/etranzact/tests.py	(revision 8020)
@@ -18,5 +18,5 @@
 from hurry.workflow.interfaces import IWorkflowState
 from waeup.kofa.students.tests.test_browser import StudentsFullSetup
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/ftesting.zcml
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/ftesting.zcml	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/ftesting.zcml	(revision 8020)
@@ -2,11 +2,11 @@
    xmlns="http://namespaces.zope.org/zope"
    xmlns:kofa="http://namespaces.waeup.org/kofa"
-   i18n_domain="waeup.custom"
-   package="waeup.custom"
+   i18n_domain="waeup.uniben"
+   package="waeup.uniben"
    >
 
   <include package="grok" />
-  <includeOverrides package="waeup.custom" />
-  <includeOverrides package="waeup.custom" file="mail.zcml"/>
+  <includeOverrides package="waeup.uniben" />
+  <includeOverrides package="waeup.uniben" file="mail.zcml"/>
 
   <!-- Where should the datacenter reside by default? -->
Index: main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/interswitch/browser.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser.py	(revision 8020)
@@ -26,6 +26,6 @@
 from waeup.kofa.students.browser import write_log_message
 from waeup.kofa.students.viewlets import RequestCallbackActionButton
-from waeup.custom.utils.utils import actions_after_payment
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.utils.utils import actions_after_payment
+from waeup.uniben.interfaces import MessageFactory as _
 
 PRODUCT_ID = '57'
Index: main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/goto_interswitch.pt
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/interswitch/browser_templates/goto_interswitch.pt	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/interswitch/browser_templates/goto_interswitch.pt	(revision 8020)
@@ -1,3 +1,3 @@
-<form i18n:domain="waeup.custom"
+<form i18n:domain="waeup.uniben"
   tal:attributes="action view/action" method="POST">
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/interswitch/tests.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/interswitch/tests.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/interswitch/tests.py	(revision 8020)
@@ -18,5 +18,5 @@
 from hurry.workflow.interfaces import IWorkflowState
 from waeup.kofa.students.tests.test_browser import StudentsFullSetup
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 
 # Also run tests that send requests to external servers?
Index: main/waeup.uniben/trunk/src/waeup/uniben/students/batching.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/students/batching.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/students/batching.py	(revision 8020)
@@ -24,5 +24,5 @@
 students, studycourses, payment tickets and accommodation tickets.
 """
-from waeup.custom.students.interfaces import (
+from waeup.uniben.students.interfaces import (
     IStudent, 
     )
Index: main/waeup.uniben/trunk/src/waeup/uniben/students/browser.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/students/browser.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/students/browser.py	(revision 8020)
@@ -27,9 +27,9 @@
     ExportPDFClearanceSlipPage)
 from waeup.kofa.students.viewlets import RequestCallbackActionButton
-from waeup.custom.students.interfaces import (
+from waeup.uniben.students.interfaces import (
     IStudent, IStudentPersonal,
     IUGStudentClearance,IPGStudentClearance,
     )
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.interfaces import MessageFactory as _
 
 class RequestCallbackActionButton(RequestCallbackActionButton):
Index: main/waeup.uniben/trunk/src/waeup/uniben/students/student.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/students/student.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/students/student.py	(revision 8020)
@@ -23,5 +23,5 @@
 from waeup.kofa.utils.helpers import attrs_to_fields
 from waeup.kofa.students.student import Student, StudentFactory
-from waeup.custom.students.interfaces import IStudent, IStudentNavigation
+from waeup.uniben.students.interfaces import IStudent, IStudentNavigation
 
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/students/tests/test_browser.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/students/tests/test_browser.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/students/tests/test_browser.py	(revision 8020)
@@ -25,6 +25,6 @@
 from waeup.kofa.testing import FunctionalTestCase
 from waeup.kofa.students.batching import StudentProcessor as StudentProcessorBase
-from waeup.custom.students.batching import StudentProcessor
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.students.batching import StudentProcessor
+from waeup.uniben.testing import FunctionalLayer
 
 STUDENT_SAMPLE_DATA = open(
Index: main/waeup.uniben/trunk/src/waeup/uniben/students/utils.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/students/utils.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/students/utils.py	(revision 8020)
@@ -20,5 +20,5 @@
 from waeup.kofa.students.utils import StudentsUtils
 from waeup.kofa.students.interfaces import IStudentsUtils
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.interfaces import MessageFactory as _
 
 def get_school_fee(student, surcharge):
Index: main/waeup.uniben/trunk/src/waeup/uniben/tests/test_configuration.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/tests/test_configuration.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/tests/test_configuration.py	(revision 8020)
@@ -25,9 +25,9 @@
 from waeup.kofa.tests.test_configuration import (
     ConfigurationTest, SessionConfigurationFactoryTest)
-from waeup.custom.configuration import (
+from waeup.uniben.configuration import (
     SessionConfiguration, SessionConfigurationFactory)
-from waeup.custom.interfaces import(
+from waeup.uniben.interfaces import(
     ISessionConfiguration, ISessionConfigurationAdd)
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 
 class ConfigurationTest(ConfigurationTest):
Index: main/waeup.uniben/trunk/src/waeup/uniben/tests/test_datacenter.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/tests/test_datacenter.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/tests/test_datacenter.py	(revision 8020)
@@ -18,5 +18,5 @@
 from waeup.kofa.datacenter import DataCenter
 from waeup.kofa.testing import FunctionalTestCase
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/tests/test_smtp.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/tests/test_smtp.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/tests/test_smtp.py	(revision 8020)
@@ -33,5 +33,5 @@
     send_mail)
 from waeup.kofa.testing import FunctionalTestCase
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 
 #
Index: main/waeup.uniben/trunk/src/waeup/uniben/utils/tests.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/utils/tests.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/utils/tests.py	(revision 8020)
@@ -17,5 +17,5 @@
 ##
 from waeup.kofa.testing import FunctionalTestCase
-from waeup.custom.testing import FunctionalLayer
+from waeup.uniben.testing import FunctionalLayer
 
 
Index: main/waeup.uniben/trunk/src/waeup/uniben/utils/utils.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/utils/utils.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/utils/utils.py	(revision 8020)
@@ -21,5 +21,5 @@
 from waeup.kofa.utils.utils import KofaUtils
 from waeup.kofa.accesscodes import create_accesscode
-from waeup.custom.interfaces import MessageFactory as _
+from waeup.uniben.interfaces import MessageFactory as _
 
 def actions_after_payment(student, payment, view):

Index: main/waeup.uniben/trunk/src/waeup/uniben/interfaces.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/interfaces.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/interfaces.py	(revision 8020)
@@ -22,5 +22,5 @@
     ISessionConfiguration, academic_sessions_vocab)
 
-_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.custom')
+_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.uniben')
 
 # It's recommended to replicate all fields from the base package here.
@@ -73,5 +73,5 @@
         )
 
     # Additional fees in waeup.custom
 
     maint_fee = schema.Float(
@@ -73,5 +73,5 @@
         )
 
-    # Additional fees in waeup.custom
+    # Additional fees in waeup.uniben
 
     maint_fee = schema.Float(
Index: main/waeup.uniben/trunk/src/waeup/uniben/testing.py
===================================================================
--- main/waeup.uniben/trunk/src/waeup/custom/testing.py	(revision 8019)
+++ main/waeup.uniben/trunk/src/waeup/uniben/testing.py	(revision 8020)
@@ -16,12 +16,12 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """Testing support for :mod:`waeup.custom`.
 """
 import os.path
-import waeup.custom
+import waeup.uniben
 from zope.app.testing.functional import ZCMLLayer
 
 ftesting_zcml = os.path.join(
-    os.path.dirname(waeup.custom.__file__), 'ftesting.zcml')
+    os.path.dirname(waeup.uniben.__file__), 'ftesting.zcml')
 FunctionalLayer = ZCMLLayer(ftesting_zcml, __name__, 'FunctionalLayer',
                             allow_teardown=True)
@@ -16,12 +16,12 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""Testing support for :mod:`waeup.custom`.
+"""Testing support for :mod:`waeup.uniben`.
 """
 import os.path